package com.akamai.mdt.captioning;

import android.app.Activity;
import android.content.DialogInterface;
import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.view.WindowManager;
import android.widget.ProgressBar;

import com.akamai.captioning.CaptionComponent;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;

public class MainActivity extends Activity implements View.OnTouchListener, IPlayerEventsListener {

    private VideoPlayerContainer mVideoContainer;

    private VideoPlayerView mVideoView;

    private ProgressBar mProgressBar;

    private Boolean mWasPlaying = false;

    private int mCurrentPosition = 0;

    private final static String LICENSE = "vsoYDD2spmkfMgkq9JEB-VqOW3PQqyG2xApx7Jqgzuc8S8LDx2PnXKw7W2eDJzCuvpd_Qe7vBszUs-yv87qXig==";

    private final static String VIDEO_URL = "http://multiplatform-f.akamaihd.net/i/multi/april11/hdworld/hdworld_,512x288_450_b,640x360_700_b,768x432_1000_b,1024x576_1400_m,1280x720_1900_m,1280x720_2500_m,1280x720_3500_m,.mp4.csmil/master.m3u8";

    // Captioning plugin
    private CaptionComponent mCaptionComponent;

    // Captioning variables
    private final String CAPTION_ASSET_URL = "http://projects.mediadev.edgesuite.net/customers/akamai/android/doc/sample.vtt";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // This prevents the device to go sleep
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        // Initialize the progress bar with the xml
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);

        // Get a reference to the VideoContainer object
        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);

        // Set the decoding mode used by the Android SDK video control
        mVideoContainer.setMode(VideoPlayerContainer.MODE_AUTOMATIC);

        // Get a reference to the VideoView object
        mVideoView = mVideoContainer.getVideoPlayer();

        // Set the progress to the player
        mVideoView.setProgressBarControl(mProgressBar);

        // Set your license
        mVideoView.setLicense(LICENSE);

        // Set the screen mode
        mVideoView.setFullScreen(true);
        mVideoView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);

        // Activate the logs
        mVideoView.setLogEnabled(true);

        // Get a reference to the Caption Component object
        mCaptionComponent = (CaptionComponent) findViewById(R.id.captionView);

        //Generate captions after configure the AMP player
        createCaptions();

        mVideoView.setEventsListener(this);
        ((View)mVideoView).setKeepScreenOn(true);
        ((View)mVideoView).setOnTouchListener(this);

        // Play the stream
        mVideoView.playUrl(VIDEO_URL);

    }

    @Override
    protected void onResume() {
        Log.d("PlayerView", "OnResume");
        if (mWasPlaying) {
            mVideoView.playUrl(VIDEO_URL, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d("PlayerView", "OnPause");
        if (mVideoView.isPlaying() || mVideoView.isPaused()) {
            mCurrentPosition = mVideoView.getTimePosition();
            mWasPlaying = true;
        }
        mVideoView.stop();
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d("PlayerView", "OnDestroy");
        mVideoView.stop();
        mVideoView.onDestroy();
        super.onDestroy();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    /**
     * Caption configuration
     */
    private void createCaptions(){
        mCaptionComponent.setVideoPlayerView(mVideoView);
        mCaptionComponent.setCaptionTextStyle(CaptionComponent.CAPTIONS_TEXT_DROP_SHADOW_STYLE);
        mCaptionComponent.setScreenPosition(CaptionComponent.CAPTION_POSITION_TOP);
        mCaptionComponent.setTextSize(22);
        mCaptionComponent.setTextBackgroundColor(Color.BLACK);
        mCaptionComponent.setTextColor(Color.YELLOW);
        mCaptionComponent.setTextWindowColor(Color.GREEN);
        mCaptionComponent.setCaptionAnimationMode(CaptionComponent.CAPTION_ANIMATION_POP_ON);

        // External VTT file, for media assets with no integrated captions
        mCaptionComponent.loadExternalVTTResource("English", "en", CAPTION_ASSET_URL);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        switch(iInEventType) {
            case IPlayerEventsListener.PLAYER_EVENT_TYPE_LOADING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_FINISHED:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_START_PLAYING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_ERROR:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_POSITION_UPDATE:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_START_REBUFFERING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_END_REBUFFERING:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SWITCH_REQUESTED:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SWITCH:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_FULLSCREEN_MODE_CHANGE:
                break;

            case IPlayerEventsListener.PLAYER_EVENT_TYPE_SIZE_CHANGE:
                break;

            default:
                break;
        }

        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        if(iInEventType == IPlayerEventsListener.PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED)
            Log.d("Player", "Event Type: PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDED (" + iInEventType + ")");

        return true;
    }

    @Override
    public boolean onTouch(View v, MotionEvent event)
    {
        return false;
    }
}